// ---------------------------------------------------------------------------
//
// main() exercises the sunRise/sunSet functions by running them against every
// day of the year.

#include                "suntimelib.h"
#include                <stdio.h>
#include                <time.h>

// ---------------------------------------------------------------------------
//
// Convert julian day (yyyymm) to gregorian date (mmdd)

void jul2greg(
    int                 year,
    int                 dayOfYear,
    int *               month,
    int *               day
    ) {

static const int        daysInMonth[]   = {0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
int                     i;
int                     leapYear        = (year % 4 == 0 && year % 100 != 0) || (year % 400 == 0);

*month = 1;
*day   = dayOfYear;

for (i = 1; i <= 12; i = i + 1) {
    int daysInCurrentMonth = daysInMonth[i] + (i == 2 && leapYear); // Adding an extra day for February in a leap year
    if (*day <= daysInCurrentMonth)
        break;
    *month = i + 1;
    *day   = *day - daysInCurrentMonth;
    }
} // jul2greg

int main(
    ) {

// Test data is for Abilene Airport
const double            gmtOffset       = -6;
const double            latitude        =  32.412075222878954;
const double            longitude       = -99.68005713370206;

time_t                  date;
int                     day;
int                     i;
int                     month;
time_t                  suntime;
struct tm               *timeInfo;
int                     year;

printf("Sunrise/Sunset Time Tester\n\n");

// Get current year
date = time(NULL);
printf("Current date is: %s\n", ctime(&date));
timeInfo = localtime(&date);
year = timeInfo->tm_year + 1900;

// loop thru every day of the year 1-365

for (i = 1; i <= 365; i = i + 1) {
    jul2greg(year, i, &month, &day);                        // convert julian to gregorian date
    printf("Day: %03d: %02d/%02d: ", i, month, day);

    // load the date into the tm struct and convert to date
    timeInfo->tm_year = year  - 1900;
    timeInfo->tm_mon  = month - 1;
    timeInfo->tm_mday = day;
    timeInfo->tm_hour = 0;
    timeInfo->tm_min  = 0;
    timeInfo->tm_sec  = 0;
    date              = mktime(timeInfo);

    suntime = sunRise(date, latitude, longitude, gmtOffset);// determine sunrise time
    timeInfo = localtime(&suntime);                         // move into tm struct
    printf("Sunrise: %02d:%02d ", timeInfo->tm_hour, timeInfo->tm_min);

    suntime = sunSet(date, latitude, longitude, gmtOffset); // determine sunset time
    timeInfo = localtime(&suntime);                         // move into tm struct
    printf("Sunset: %02d:%02d ", timeInfo->tm_hour, timeInfo->tm_min);
    printf("\n");
    } // for

return 0;

} // main


